[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] x86: Do not restrict 32-bit EPT to 4GB.



# HG changeset patch
# User Keir Fraser <keir.fraser@xxxxxxxxxx>
# Date 1230557552 0
# Node ID 0af9fbf3f05306d4972cf05e4b6d7be2199a41cb
# Parent  c54d6f871de8f271aaeb571c3b87eae9165e3183
x86: Do not restrict 32-bit EPT to 4GB.

Signed-off-by: Xin, Xiaohui <xiaohui.xin@xxxxxxxxx>
---
 xen/arch/x86/mm/p2m.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff -r c54d6f871de8 -r 0af9fbf3f053 xen/arch/x86/mm/p2m.c
--- a/xen/arch/x86/mm/p2m.c     Mon Dec 29 13:30:14 2008 +0000
+++ b/xen/arch/x86/mm/p2m.c     Mon Dec 29 13:32:32 2008 +0000
@@ -935,11 +935,12 @@ guest_physmap_add_entry(struct domain *d
 
 #if CONFIG_PAGING_LEVELS == 3
     /*
      * 32bit PAE nested paging does not support over 4GB guest due to 
      * hardware translation limit. This limitation is checked by comparing
      * gfn with 0xfffffUL.
      */
-    if ( paging_mode_hap(d) && (gfn > 0xfffffUL) )
+    if ( paging_mode_hap(d) && (gfn > 0xfffffUL) &&
+         (boot_cpu_data.x86_vendor == X86_VENDOR_AMD) )
     {
         if ( !test_and_set_bool(d->arch.hvm_domain.svm.npt_4gb_warning) )
             dprintk(XENLOG_WARNING, "Dom%d failed to populate memory beyond"
@@ -935,11 +935,12 @@ guest_physmap_add_entry(struct domain *d
 #if CONFIG_PAGING_LEVELS == 3
     /*
-     * 32bit PAE nested paging does not support over 4GB guest due to 
+     * 32bit AMD nested paging does not support over 4GB guest due to 
      * hardware translation limit. This limitation is checked by comparing
      * gfn with 0xfffffUL.

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.